pub trait FoundryChain<Tx>:
Clone
+ Debug
+ Default
+ Send
+ Sync {
// Provided methods
fn for_transaction(_tx: &Tx) -> Self { ... }
fn for_block(
_grandparent: &[Tx],
_parent: &[Tx],
_current: &[Tx],
_current_tx_index: usize,
) -> Self { ... }
fn refresh_journal<J>(&self, _journal: &mut J)
where J: FoundryJournal { ... }
}Expand description
Foundry extension for chain context type
Every family that doesn’t need chain metadata uses ().
Provided Methods
Sourcefn for_transaction(_tx: &Tx) -> Self
fn for_transaction(_tx: &Tx) -> Self
Builds chain context for a standalone synthetic transaction.
Sourcefn for_block(
_grandparent: &[Tx],
_parent: &[Tx],
_current: &[Tx],
_current_tx_index: usize,
) -> Self
fn for_block( _grandparent: &[Tx], _parent: &[Tx], _current: &[Tx], _current_tx_index: usize, ) -> Self
Builds chain context for a transaction at an exact block position.
Sourcefn refresh_journal<J>(&self, _journal: &mut J)where
J: FoundryJournal,
fn refresh_journal<J>(&self, _journal: &mut J)where
J: FoundryJournal,
Refreshes journal state derived from the active chain position.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".